package org.eclipse.jdt.internal.compiler.ast;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.util.List;
import org.eclipse.jdt.internal.compiler.ASTVisitor;
import org.eclipse.jdt.internal.compiler.ast.AbstractVariableDeclaration;
import org.eclipse.jdt.internal.compiler.ast.Annotation;
import org.eclipse.jdt.internal.compiler.ast.Javadoc;
import org.eclipse.jdt.internal.compiler.ast.NullAnnotationMatching;
import org.eclipse.jdt.internal.compiler.ast.TypeReference;
import org.eclipse.jdt.internal.compiler.codegen.CodeStream;
import org.eclipse.jdt.internal.compiler.flow.FlowContext;
import org.eclipse.jdt.internal.compiler.flow.FlowInfo;
import org.eclipse.jdt.internal.compiler.flow.UnconditionalFlowInfo;
import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
import org.eclipse.jdt.internal.compiler.impl.Constant;
import org.eclipse.jdt.internal.compiler.lookup.BlockScope;
import org.eclipse.jdt.internal.compiler.lookup.FieldBinding;
import org.eclipse.jdt.internal.compiler.lookup.MethodScope;
import org.eclipse.jdt.internal.compiler.lookup.Scope;
import org.eclipse.jdt.internal.compiler.lookup.SourceTypeBinding;
import org.eclipse.jdt.internal.compiler.lookup.VariableBinding;

public class FieldDeclaration extends AbstractVariableDeclaration {
  public FieldBinding binding;
  
  public Javadoc javadoc;
  
  public int endPart1Position;
  
  public int endPart2Position;
  
  public FieldDeclaration() {}
  
  public FieldDeclaration(char[] name, int sourceStart, int sourceEnd) {
    this.name = name;
    this.sourceStart = sourceStart;
    this.sourceEnd = sourceEnd;
  }
  
  public FlowInfo analyseCode(MethodScope initializationScope, FlowContext flowContext, FlowInfo flowInfo) {
    UnconditionalFlowInfo unconditionalFlowInfo;
    if (this.binding != null && !this.binding.isUsed() && this.binding.isOrEnclosedByPrivateType() && 
      !(initializationScope.referenceCompilationUnit()).compilationResult.hasSyntaxError)
      initializationScope.problemReporter().unusedPrivateField(this); 
    if (this.binding != null && 
      this.binding.isValidBinding() && 
      this.binding.isStatic() && 
      this.binding.constant((Scope)initializationScope) == Constant.NotAConstant && 
      this.binding.declaringClass.isNestedType() && 
      !this.binding.declaringClass.isStatic())
      initializationScope.problemReporter().unexpectedStaticModifierForField(
          (SourceTypeBinding)this.binding.declaringClass, 
          this); 
    if (this.initialization != null) {
      unconditionalFlowInfo = 
        this.initialization
        .analyseCode((BlockScope)initializationScope, flowContext, flowInfo)
        .unconditionalInits();
      unconditionalFlowInfo.markAsDefinitelyAssigned(this.binding);
    } 
    if (this.initialization != null && this.binding != null) {
      CompilerOptions options = initializationScope.compilerOptions();
      if (options.isAnnotationBasedNullAnalysisEnabled && (
        this.binding.isNonNull() || options.sourceLevel >= 3407872L)) {
        int nullStatus = this.initialization.nullStatus((FlowInfo)unconditionalFlowInfo, flowContext);
        NullAnnotationMatching.checkAssignment((BlockScope)initializationScope, flowContext, (VariableBinding)this.binding, (FlowInfo)unconditionalFlowInfo, nullStatus, this.initialization, this.initialization.resolvedType);
      } 
      this.initialization.checkNPEbyUnboxing((BlockScope)initializationScope, flowContext, (FlowInfo)unconditionalFlowInfo);
    } 
    return (FlowInfo)unconditionalFlowInfo;
  }
  
  public void generateCode(BlockScope currentScope, CodeStream codeStream) {
    if ((this.bits & Integer.MIN_VALUE) == 0)
      return; 
    int pc = codeStream.position;
    boolean isStatic;
    if (this.initialization != null && (
      !(isStatic = this.binding.isStatic()) || this.binding.constant() == Constant.NotAConstant)) {
      if (!isStatic)
        codeStream.aload_0(); 
      this.initialization.generateCode(currentScope, codeStream, true);
      if (isStatic) {
        codeStream.fieldAccess((byte)-77, this.binding, null);
      } else {
        codeStream.fieldAccess((byte)-75, this.binding, null);
      } 
    } 
    codeStream.recordPositionsFrom(pc, this.sourceStart);
  }
  
  public void getAllAnnotationContexts(int targetType, List allAnnotationContexts) {
    TypeReference.AnnotationCollector collector = new TypeReference.AnnotationCollector(this.type, targetType, allAnnotationContexts);
    for (int i = 0, max = this.annotations.length; i < max; i++) {
      Annotation annotation = this.annotations[i];
      annotation.traverse((ASTVisitor)collector, null);
    } 
  }
  
  public int getKind() {
    return (this.type == null) ? 3 : 1;
  }
  
  public boolean isStatic() {
    if (this.binding != null)
      return this.binding.isStatic(); 
    return ((this.modifiers & 0x8) != 0);
  }
  
  public boolean isFinal() {
    if (this.binding != null)
      return this.binding.isFinal(); 
    return ((this.modifiers & 0x10) != 0);
  }
  
  public StringBuffer printStatement(int indent, StringBuffer output) {
    if (this.javadoc != null)
      this.javadoc.print(indent, output); 
    return super.printStatement(indent, output);
  }
  
  public void resolve(MethodScope initializationScope) {
    // Byte code:
    //   0: aload_0
    //   1: getfield bits : I
    //   4: bipush #16
    //   6: iand
    //   7: ifeq -> 11
    //   10: return
    //   11: aload_0
    //   12: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   15: ifnull -> 28
    //   18: aload_0
    //   19: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   22: invokevirtual isValidBinding : ()Z
    //   25: ifne -> 29
    //   28: return
    //   29: aload_0
    //   30: dup
    //   31: getfield bits : I
    //   34: bipush #16
    //   36: ior
    //   37: putfield bits : I
    //   40: aload_1
    //   41: invokevirtual enclosingClassScope : ()Lorg/eclipse/jdt/internal/compiler/lookup/ClassScope;
    //   44: astore_2
    //   45: aload_2
    //   46: ifnull -> 263
    //   49: aload_2
    //   50: invokevirtual enclosingSourceType : ()Lorg/eclipse/jdt/internal/compiler/lookup/SourceTypeBinding;
    //   53: astore_3
    //   54: aload_3
    //   55: getfield superclass : Lorg/eclipse/jdt/internal/compiler/lookup/ReferenceBinding;
    //   58: ifnonnull -> 64
    //   61: goto -> 142
    //   64: aload_2
    //   65: aload_3
    //   66: getfield superclass : Lorg/eclipse/jdt/internal/compiler/lookup/ReferenceBinding;
    //   69: aload_0
    //   70: getfield name : [C
    //   73: aload_0
    //   74: iconst_0
    //   75: iconst_1
    //   76: invokevirtual findField : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;[CLorg/eclipse/jdt/internal/compiler/lookup/InvocationSite;ZZ)Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   79: astore #4
    //   81: aload #4
    //   83: ifnonnull -> 89
    //   86: goto -> 142
    //   89: aload #4
    //   91: invokevirtual isValidBinding : ()Z
    //   94: ifne -> 100
    //   97: goto -> 142
    //   100: aload #4
    //   102: invokevirtual original : ()Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   105: aload_0
    //   106: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   109: if_acmpne -> 115
    //   112: goto -> 142
    //   115: aload #4
    //   117: aload_3
    //   118: aload_0
    //   119: aload_1
    //   120: invokevirtual canBeSeenBy : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/InvocationSite;Lorg/eclipse/jdt/internal/compiler/lookup/Scope;)Z
    //   123: ifne -> 129
    //   126: goto -> 142
    //   129: aload_1
    //   130: invokevirtual problemReporter : ()Lorg/eclipse/jdt/internal/compiler/problem/ProblemReporter;
    //   133: aload_0
    //   134: aload #4
    //   136: invokevirtual fieldHiding : (Lorg/eclipse/jdt/internal/compiler/ast/FieldDeclaration;Lorg/eclipse/jdt/internal/compiler/lookup/Binding;)V
    //   139: goto -> 263
    //   142: aload_2
    //   143: getfield parent : Lorg/eclipse/jdt/internal/compiler/lookup/Scope;
    //   146: astore #4
    //   148: aload #4
    //   150: getfield kind : I
    //   153: iconst_4
    //   154: if_icmpne -> 160
    //   157: goto -> 263
    //   160: aload #4
    //   162: aload_0
    //   163: getfield name : [C
    //   166: iconst_3
    //   167: aload_0
    //   168: iconst_0
    //   169: invokevirtual getBinding : ([CILorg/eclipse/jdt/internal/compiler/lookup/InvocationSite;Z)Lorg/eclipse/jdt/internal/compiler/lookup/Binding;
    //   172: astore #5
    //   174: aload #5
    //   176: ifnonnull -> 182
    //   179: goto -> 263
    //   182: aload #5
    //   184: invokevirtual isValidBinding : ()Z
    //   187: ifne -> 193
    //   190: goto -> 263
    //   193: aload #5
    //   195: aload_0
    //   196: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   199: if_acmpne -> 205
    //   202: goto -> 263
    //   205: aload #5
    //   207: instanceof org/eclipse/jdt/internal/compiler/lookup/FieldBinding
    //   210: ifeq -> 253
    //   213: aload #5
    //   215: checkcast org/eclipse/jdt/internal/compiler/lookup/FieldBinding
    //   218: astore #6
    //   220: aload #6
    //   222: invokevirtual original : ()Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   225: aload_0
    //   226: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   229: if_acmpne -> 235
    //   232: goto -> 263
    //   235: aload #6
    //   237: invokevirtual isStatic : ()Z
    //   240: ifne -> 253
    //   243: aload_3
    //   244: invokevirtual isStatic : ()Z
    //   247: ifeq -> 253
    //   250: goto -> 263
    //   253: aload_1
    //   254: invokevirtual problemReporter : ()Lorg/eclipse/jdt/internal/compiler/problem/ProblemReporter;
    //   257: aload_0
    //   258: aload #5
    //   260: invokevirtual fieldHiding : (Lorg/eclipse/jdt/internal/compiler/ast/FieldDeclaration;Lorg/eclipse/jdt/internal/compiler/lookup/Binding;)V
    //   263: aload_0
    //   264: getfield type : Lorg/eclipse/jdt/internal/compiler/ast/TypeReference;
    //   267: ifnull -> 284
    //   270: aload_0
    //   271: getfield type : Lorg/eclipse/jdt/internal/compiler/ast/TypeReference;
    //   274: aload_0
    //   275: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   278: getfield type : Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   281: putfield resolvedType : Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   284: aload_1
    //   285: getfield initializedField : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   288: astore_3
    //   289: aload_1
    //   290: getfield lastVisibleFieldID : I
    //   293: istore #4
    //   295: aload_1
    //   296: aload_0
    //   297: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   300: putfield initializedField : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   303: aload_1
    //   304: aload_0
    //   305: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   308: getfield id : I
    //   311: putfield lastVisibleFieldID : I
    //   314: aload_1
    //   315: aload_0
    //   316: getfield annotations : [Lorg/eclipse/jdt/internal/compiler/ast/Annotation;
    //   319: aload_0
    //   320: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   323: invokestatic resolveAnnotations : (Lorg/eclipse/jdt/internal/compiler/lookup/BlockScope;[Lorg/eclipse/jdt/internal/compiler/ast/Annotation;Lorg/eclipse/jdt/internal/compiler/lookup/Binding;)V
    //   326: aload_0
    //   327: getfield annotations : [Lorg/eclipse/jdt/internal/compiler/ast/Annotation;
    //   330: ifnull -> 402
    //   333: iconst_0
    //   334: istore #5
    //   336: aload_0
    //   337: getfield annotations : [Lorg/eclipse/jdt/internal/compiler/ast/Annotation;
    //   340: arraylength
    //   341: istore #6
    //   343: goto -> 395
    //   346: aload_0
    //   347: getfield annotations : [Lorg/eclipse/jdt/internal/compiler/ast/Annotation;
    //   350: iload #5
    //   352: aaload
    //   353: getfield resolvedType : Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   356: astore #7
    //   358: aload #7
    //   360: ifnull -> 392
    //   363: aload #7
    //   365: invokevirtual getAnnotationTagBits : ()J
    //   368: ldc2_w 9007199254740992
    //   371: land
    //   372: lconst_0
    //   373: lcmp
    //   374: ifeq -> 392
    //   377: aload_0
    //   378: dup
    //   379: getfield bits : I
    //   382: ldc_w 1048576
    //   385: ior
    //   386: putfield bits : I
    //   389: goto -> 402
    //   392: iinc #5, 1
    //   395: iload #5
    //   397: iload #6
    //   399: if_icmplt -> 346
    //   402: aload_0
    //   403: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   406: invokevirtual getAnnotationTagBits : ()J
    //   409: ldc2_w 70368744177664
    //   412: land
    //   413: lconst_0
    //   414: lcmp
    //   415: ifne -> 454
    //   418: aload_0
    //   419: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   422: getfield modifiers : I
    //   425: ldc_w 1048576
    //   428: iand
    //   429: ifeq -> 454
    //   432: aload_1
    //   433: invokevirtual compilerOptions : ()Lorg/eclipse/jdt/internal/compiler/impl/CompilerOptions;
    //   436: getfield sourceLevel : J
    //   439: ldc2_w 3211264
    //   442: lcmp
    //   443: iflt -> 454
    //   446: aload_1
    //   447: invokevirtual problemReporter : ()Lorg/eclipse/jdt/internal/compiler/problem/ProblemReporter;
    //   450: aload_0
    //   451: invokevirtual missingDeprecatedAnnotationForField : (Lorg/eclipse/jdt/internal/compiler/ast/FieldDeclaration;)V
    //   454: aload_0
    //   455: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   458: ifnonnull -> 474
    //   461: aload_0
    //   462: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   465: getstatic org/eclipse/jdt/internal/compiler/impl/Constant.NotAConstant : Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   468: invokevirtual setConstant : (Lorg/eclipse/jdt/internal/compiler/impl/Constant;)V
    //   471: goto -> 892
    //   474: aload_0
    //   475: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   478: getstatic org/eclipse/jdt/internal/compiler/impl/Constant.NotAConstant : Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   481: invokevirtual setConstant : (Lorg/eclipse/jdt/internal/compiler/impl/Constant;)V
    //   484: aload_0
    //   485: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   488: getfield type : Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   491: astore #5
    //   493: aload_0
    //   494: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   497: getstatic org/eclipse/jdt/internal/compiler/ast/ExpressionContext.ASSIGNMENT_CONTEXT : Lorg/eclipse/jdt/internal/compiler/ast/ExpressionContext;
    //   500: invokevirtual setExpressionContext : (Lorg/eclipse/jdt/internal/compiler/ast/ExpressionContext;)V
    //   503: aload_0
    //   504: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   507: aload #5
    //   509: invokevirtual setExpectedType : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)V
    //   512: aload_0
    //   513: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   516: instanceof org/eclipse/jdt/internal/compiler/ast/ArrayInitializer
    //   519: ifeq -> 568
    //   522: aload_0
    //   523: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   526: aload_1
    //   527: aload #5
    //   529: invokevirtual resolveTypeExpecting : (Lorg/eclipse/jdt/internal/compiler/lookup/BlockScope;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   532: dup
    //   533: astore #6
    //   535: ifnull -> 866
    //   538: aload_0
    //   539: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   542: checkcast org/eclipse/jdt/internal/compiler/ast/ArrayInitializer
    //   545: aload #6
    //   547: checkcast org/eclipse/jdt/internal/compiler/lookup/ArrayBinding
    //   550: putfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/ArrayBinding;
    //   553: aload_0
    //   554: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   557: aload_1
    //   558: aload #5
    //   560: aload #6
    //   562: invokevirtual computeConversion : (Lorg/eclipse/jdt/internal/compiler/lookup/Scope;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)V
    //   565: goto -> 866
    //   568: aload_0
    //   569: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   572: aload_1
    //   573: invokevirtual resolveType : (Lorg/eclipse/jdt/internal/compiler/lookup/BlockScope;)Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   576: dup
    //   577: astore #6
    //   579: ifnull -> 856
    //   582: aload #5
    //   584: aload #6
    //   586: invokestatic notEquals : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)Z
    //   589: ifeq -> 603
    //   592: aload_1
    //   593: invokevirtual compilationUnitScope : ()Lorg/eclipse/jdt/internal/compiler/lookup/CompilationUnitScope;
    //   596: aload #5
    //   598: aload #6
    //   600: invokevirtual recordTypeConversion : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)V
    //   603: aload_0
    //   604: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   607: aload #6
    //   609: aload #5
    //   611: invokevirtual isConstantValueOfTypeAssignableToType : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)Z
    //   614: ifne -> 628
    //   617: aload #6
    //   619: aload #5
    //   621: aload_2
    //   622: invokevirtual isCompatibleWith : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/Scope;)Z
    //   625: ifeq -> 705
    //   628: aload_0
    //   629: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   632: aload_1
    //   633: aload #5
    //   635: aload #6
    //   637: invokevirtual computeConversion : (Lorg/eclipse/jdt/internal/compiler/lookup/Scope;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)V
    //   640: aload #6
    //   642: aload #5
    //   644: invokevirtual needsUncheckedConversion : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)Z
    //   647: ifeq -> 665
    //   650: aload_1
    //   651: invokevirtual problemReporter : ()Lorg/eclipse/jdt/internal/compiler/problem/ProblemReporter;
    //   654: aload_0
    //   655: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   658: aload #6
    //   660: aload #5
    //   662: invokevirtual unsafeTypeConversion : (Lorg/eclipse/jdt/internal/compiler/ast/Expression;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)V
    //   665: aload_0
    //   666: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   669: instanceof org/eclipse/jdt/internal/compiler/ast/CastExpression
    //   672: ifeq -> 803
    //   675: aload_0
    //   676: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   679: getfield bits : I
    //   682: sipush #16384
    //   685: iand
    //   686: ifne -> 803
    //   689: aload_1
    //   690: aload #5
    //   692: aload_0
    //   693: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   696: checkcast org/eclipse/jdt/internal/compiler/ast/CastExpression
    //   699: invokestatic checkNeedForAssignedCast : (Lorg/eclipse/jdt/internal/compiler/lookup/BlockScope;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/ast/CastExpression;)V
    //   702: goto -> 803
    //   705: aload_0
    //   706: aload #6
    //   708: aload #5
    //   710: aload_0
    //   711: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   714: aload_1
    //   715: invokevirtual isBoxingCompatible : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/ast/Expression;Lorg/eclipse/jdt/internal/compiler/lookup/Scope;)Z
    //   718: ifeq -> 773
    //   721: aload_0
    //   722: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   725: aload_1
    //   726: aload #5
    //   728: aload #6
    //   730: invokevirtual computeConversion : (Lorg/eclipse/jdt/internal/compiler/lookup/Scope;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;)V
    //   733: aload_0
    //   734: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   737: instanceof org/eclipse/jdt/internal/compiler/ast/CastExpression
    //   740: ifeq -> 803
    //   743: aload_0
    //   744: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   747: getfield bits : I
    //   750: sipush #16384
    //   753: iand
    //   754: ifne -> 803
    //   757: aload_1
    //   758: aload #5
    //   760: aload_0
    //   761: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   764: checkcast org/eclipse/jdt/internal/compiler/ast/CastExpression
    //   767: invokestatic checkNeedForAssignedCast : (Lorg/eclipse/jdt/internal/compiler/lookup/BlockScope;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/ast/CastExpression;)V
    //   770: goto -> 803
    //   773: aload #5
    //   775: getfield tagBits : J
    //   778: ldc2_w 128
    //   781: land
    //   782: lconst_0
    //   783: lcmp
    //   784: ifne -> 803
    //   787: aload_1
    //   788: invokevirtual problemReporter : ()Lorg/eclipse/jdt/internal/compiler/problem/ProblemReporter;
    //   791: aload #6
    //   793: aload #5
    //   795: aload_0
    //   796: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   799: aconst_null
    //   800: invokevirtual typeMismatchError : (Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;Lorg/eclipse/jdt/internal/compiler/ast/ASTNode;Lorg/eclipse/jdt/internal/compiler/ast/ASTNode;)V
    //   803: aload_0
    //   804: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   807: invokevirtual isFinal : ()Z
    //   810: ifeq -> 866
    //   813: aload_0
    //   814: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   817: aload_0
    //   818: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   821: getfield constant : Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   824: aload_0
    //   825: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   828: getfield type : Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   831: getfield id : I
    //   834: iconst_4
    //   835: ishl
    //   836: aload_0
    //   837: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   840: getfield constant : Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   843: invokevirtual typeID : ()I
    //   846: iadd
    //   847: invokevirtual castTo : (I)Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   850: invokevirtual setConstant : (Lorg/eclipse/jdt/internal/compiler/impl/Constant;)V
    //   853: goto -> 866
    //   856: aload_0
    //   857: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   860: getstatic org/eclipse/jdt/internal/compiler/impl/Constant.NotAConstant : Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   863: invokevirtual setConstant : (Lorg/eclipse/jdt/internal/compiler/impl/Constant;)V
    //   866: aload_0
    //   867: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   870: aload_0
    //   871: getfield initialization : Lorg/eclipse/jdt/internal/compiler/ast/Expression;
    //   874: invokestatic getDirectBinding : (Lorg/eclipse/jdt/internal/compiler/ast/Expression;)Lorg/eclipse/jdt/internal/compiler/lookup/Binding;
    //   877: if_acmpne -> 892
    //   880: aload_1
    //   881: invokevirtual problemReporter : ()Lorg/eclipse/jdt/internal/compiler/problem/ProblemReporter;
    //   884: aload_0
    //   885: aload_0
    //   886: getfield name : [C
    //   889: invokevirtual assignmentHasNoEffect : (Lorg/eclipse/jdt/internal/compiler/ast/AbstractVariableDeclaration;[C)V
    //   892: aload_0
    //   893: getfield javadoc : Lorg/eclipse/jdt/internal/compiler/ast/Javadoc;
    //   896: ifnull -> 910
    //   899: aload_0
    //   900: getfield javadoc : Lorg/eclipse/jdt/internal/compiler/ast/Javadoc;
    //   903: aload_1
    //   904: invokevirtual resolve : (Lorg/eclipse/jdt/internal/compiler/lookup/MethodScope;)V
    //   907: goto -> 1063
    //   910: aload_0
    //   911: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   914: ifnull -> 1063
    //   917: aload_0
    //   918: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   921: getfield declaringClass : Lorg/eclipse/jdt/internal/compiler/lookup/ReferenceBinding;
    //   924: ifnull -> 1063
    //   927: aload_0
    //   928: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   931: getfield declaringClass : Lorg/eclipse/jdt/internal/compiler/lookup/ReferenceBinding;
    //   934: invokevirtual isLocalType : ()Z
    //   937: ifne -> 1063
    //   940: aload_0
    //   941: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   944: getfield modifiers : I
    //   947: bipush #7
    //   949: iand
    //   950: istore #5
    //   952: aload_1
    //   953: invokevirtual problemReporter : ()Lorg/eclipse/jdt/internal/compiler/problem/ProblemReporter;
    //   956: astore #6
    //   958: aload #6
    //   960: ldc_w -1610612250
    //   963: invokevirtual computeSeverity : (I)I
    //   966: istore #7
    //   968: iload #7
    //   970: sipush #256
    //   973: if_icmpeq -> 1063
    //   976: aload_2
    //   977: ifnull -> 991
    //   980: aload_2
    //   981: invokevirtual referenceType : ()Lorg/eclipse/jdt/internal/compiler/ast/TypeDeclaration;
    //   984: iload #5
    //   986: invokestatic computeOuterMostVisibility : (Lorg/eclipse/jdt/internal/compiler/ast/TypeDeclaration;I)I
    //   989: istore #5
    //   991: aload_0
    //   992: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   995: getfield modifiers : I
    //   998: bipush #-8
    //   1000: iand
    //   1001: iload #5
    //   1003: ior
    //   1004: istore #8
    //   1006: aload #6
    //   1008: aload_0
    //   1009: getfield sourceStart : I
    //   1012: aload_0
    //   1013: getfield sourceEnd : I
    //   1016: iload #7
    //   1018: iload #8
    //   1020: invokevirtual javadocMissing : (IIII)V
    //   1023: goto -> 1063
    //   1026: astore #9
    //   1028: aload_1
    //   1029: aload_3
    //   1030: putfield initializedField : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   1033: aload_1
    //   1034: iload #4
    //   1036: putfield lastVisibleFieldID : I
    //   1039: aload_0
    //   1040: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   1043: aload_1
    //   1044: invokevirtual constant : (Lorg/eclipse/jdt/internal/compiler/lookup/Scope;)Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   1047: ifnonnull -> 1060
    //   1050: aload_0
    //   1051: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   1054: getstatic org/eclipse/jdt/internal/compiler/impl/Constant.NotAConstant : Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   1057: invokevirtual setConstant : (Lorg/eclipse/jdt/internal/compiler/impl/Constant;)V
    //   1060: aload #9
    //   1062: athrow
    //   1063: aload_1
    //   1064: aload_3
    //   1065: putfield initializedField : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   1068: aload_1
    //   1069: iload #4
    //   1071: putfield lastVisibleFieldID : I
    //   1074: aload_0
    //   1075: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   1078: aload_1
    //   1079: invokevirtual constant : (Lorg/eclipse/jdt/internal/compiler/lookup/Scope;)Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   1082: ifnonnull -> 1095
    //   1085: aload_0
    //   1086: getfield binding : Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   1089: getstatic org/eclipse/jdt/internal/compiler/impl/Constant.NotAConstant : Lorg/eclipse/jdt/internal/compiler/impl/Constant;
    //   1092: invokevirtual setConstant : (Lorg/eclipse/jdt/internal/compiler/impl/Constant;)V
    //   1095: return
    // Line number table:
    //   Java source line number -> byte code offset
    //   #177	-> 0
    //   #178	-> 11
    //   #180	-> 29
    //   #184	-> 40
    //   #186	-> 45
    //   #188	-> 49
    //   #190	-> 54
    //   #194	-> 64
    //   #195	-> 81
    //   #196	-> 89
    //   #197	-> 100
    //   #198	-> 115
    //   #200	-> 129
    //   #201	-> 139
    //   #205	-> 142
    //   #206	-> 148
    //   #207	-> 160
    //   #208	-> 174
    //   #209	-> 182
    //   #210	-> 193
    //   #211	-> 205
    //   #212	-> 213
    //   #213	-> 220
    //   #214	-> 235
    //   #217	-> 253
    //   #221	-> 263
    //   #222	-> 270
    //   #225	-> 284
    //   #226	-> 289
    //   #228	-> 295
    //   #229	-> 303
    //   #231	-> 314
    //   #233	-> 326
    //   #234	-> 333
    //   #235	-> 346
    //   #236	-> 358
    //   #237	-> 377
    //   #238	-> 389
    //   #234	-> 392
    //   #244	-> 402
    //   #245	-> 418
    //   #246	-> 432
    //   #247	-> 446
    //   #250	-> 454
    //   #251	-> 461
    //   #252	-> 471
    //   #254	-> 474
    //   #256	-> 484
    //   #258	-> 493
    //   #259	-> 503
    //   #260	-> 512
    //   #262	-> 522
    //   #263	-> 538
    //   #264	-> 553
    //   #266	-> 565
    //   #268	-> 582
    //   #269	-> 592
    //   #270	-> 603
    //   #271	-> 617
    //   #272	-> 628
    //   #273	-> 640
    //   #274	-> 650
    //   #276	-> 665
    //   #277	-> 675
    //   #278	-> 689
    //   #280	-> 702
    //   #281	-> 721
    //   #282	-> 733
    //   #283	-> 743
    //   #284	-> 757
    //   #286	-> 770
    //   #287	-> 773
    //   #289	-> 787
    //   #292	-> 803
    //   #293	-> 813
    //   #295	-> 853
    //   #296	-> 856
    //   #299	-> 866
    //   #300	-> 880
    //   #304	-> 892
    //   #305	-> 899
    //   #306	-> 907
    //   #308	-> 940
    //   #309	-> 952
    //   #310	-> 958
    //   #311	-> 968
    //   #312	-> 976
    //   #313	-> 980
    //   #315	-> 991
    //   #316	-> 1006
    //   #319	-> 1023
    //   #320	-> 1028
    //   #321	-> 1033
    //   #322	-> 1039
    //   #323	-> 1050
    //   #324	-> 1060
    //   #320	-> 1063
    //   #321	-> 1068
    //   #322	-> 1074
    //   #323	-> 1085
    //   #325	-> 1095
    // Local variable table:
    //   start	length	slot	name	descriptor
    //   0	1096	0	this	Lorg/eclipse/jdt/internal/compiler/ast/FieldDeclaration;
    //   0	1096	1	initializationScope	Lorg/eclipse/jdt/internal/compiler/lookup/MethodScope;
    //   45	1051	2	classScope	Lorg/eclipse/jdt/internal/compiler/lookup/ClassScope;
    //   54	209	3	declaringType	Lorg/eclipse/jdt/internal/compiler/lookup/SourceTypeBinding;
    //   81	61	4	existingVariable	Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   148	115	4	outerScope	Lorg/eclipse/jdt/internal/compiler/lookup/Scope;
    //   174	89	5	existingVariable	Lorg/eclipse/jdt/internal/compiler/lookup/Binding;
    //   220	33	6	existingField	Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   289	807	3	previousField	Lorg/eclipse/jdt/internal/compiler/lookup/FieldBinding;
    //   295	801	4	previousFieldID	I
    //   336	66	5	i	I
    //   343	59	6	max	I
    //   358	34	7	resolvedAnnotationType	Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   493	399	5	fieldType	Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   535	33	6	initializationType	Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   579	313	6	initializationType	Lorg/eclipse/jdt/internal/compiler/lookup/TypeBinding;
    //   952	71	5	javadocVisibility	I
    //   958	65	6	reporter	Lorg/eclipse/jdt/internal/compiler/problem/ProblemReporter;
    //   968	55	7	severity	I
    //   1006	17	8	javadocModifiers	I
    // Exception table:
    //   from	to	target	type
    //   295	1026	1026	finally
  }
  
  public void traverse(ASTVisitor visitor, MethodScope scope) {
    if (visitor.visit(this, scope)) {
      if (this.javadoc != null)
        this.javadoc.traverse(visitor, (BlockScope)scope); 
      if (this.annotations != null) {
        int annotationsLength = this.annotations.length;
        for (int i = 0; i < annotationsLength; i++)
          this.annotations[i].traverse(visitor, (BlockScope)scope); 
      } 
      if (this.type != null)
        this.type.traverse(visitor, (BlockScope)scope); 
      if (this.initialization != null)
        this.initialization.traverse(visitor, (BlockScope)scope); 
    } 
    visitor.endVisit(this, scope);
  }
}
